! { dg-do compile }
! This is the list of intrinsics allowed as actual arguments
 intrinsic abs,acos,acosh,aimag,aint,alog,alog10,amod,anint,asin,asinh,atan,&
 atan2,atanh,cabs,ccos,cexp,clog,conjg,cos,cosh,csin,csqrt,dabs,dacos,&
 dacosh,dasin,dasinh,datan,datan2,datanh,dconjg,dcos,dcosh,ddim,dexp,dim,&
 dimag,dint,dlog,dlog10,dmod,dnint,dprod,dsign,dsin,dsinh,dsqrt,dtan,dtanh,&
 exp,iabs,idim,idnint,index,isign,len,mod,nint,sign,sin,sinh,sqrt,tan,&
 tanh,zabs,zcos,zexp,zlog,zsin,zsqrt
 
  call foo(abs)
  call foo(acos)
  call foo(acosh)
  call foo(aimag)
  call foo(aint)
  call foo(alog)
  call foo(alog10)
  call foo(amod)
  call foo(anint)
  call foo(asin)
  call foo(asinh)
  call foo(atan)
  call foo(atan2)
  call foo(atanh)
  call foo(cabs)
  call foo(ccos)
  call foo(cexp)
  call foo(clog)
  call foo(conjg)
  call foo(cos)
  call foo(cosh)
  call foo(csin)
  call foo(csqrt)
  call foo(dabs)
  call foo(dacos)
  call foo(dacosh)
  call foo(dasin)
  call foo(dasinh)
  call foo(datan)
  call foo(datan2)
  call foo(datanh)
  call foo(dconjg)
  call foo(dcos)
  call foo(dcosh)
  call foo(ddim)
  call foo(dexp)
  call foo(dim)
  call foo(dimag)
  call foo(dint)
  call foo(dlog)
  call foo(dlog10)
  call foo(dmod)
  call foo(dnint)
  call foo(dprod)
  call foo(dsign)
  call foo(dsin)
  call foo(dsinh)
  call foo(dsqrt)
  call foo(dtan)
  call foo(dtanh)
  call foo(exp)
  call foo(iabs)
  call foo(idim)
  call foo(idnint)
  call foo(index)
  call foo(isign)
  call foo(len)
  call foo(mod)
  call foo(nint)
  call foo(sign)
  call foo(sin)
  call foo(sinh)
  call foo(sqrt)
  call foo(tan)
  call foo(tanh)
  call foo(zabs)
  call foo(zcos)
  call foo(zexp)
  call foo(zlog)
  call foo(zsin)
  call foo(zsqrt)
  end
